LaTeXflavor = {"numu": r'$\nu_\mu$',
               "numubar": r'$\bar{\nu}_\mu$',
               "nue": r'$\nu_e$',
               "nuebar": r'$\bar{\nu}_e$',
               "nutau": r'$\nu_\tau$',
               "nutaubar": r'$\bar{\nu}_\tau$'}



import matplotlib

matplotlib.rc('font', **{"family": 'sans-serif',
                         "sans-serif": 'Arial',
                         "size": 16,
                         "weight": 'bold'})
matplotlib.rc('font', **{"family": 'sans-serif',
                         "sans-serif": 'Arial',
                         "size": 16,
                         "weight": 'bold'})
matplotlib.rc('text', **{"usetex": True})
matplotlib.rc('lines', **{"linewidth": 3})
matplotlib.rc('hist', **{"bins": 26})
matplotlib.rc('savefig', **{"dpi": 300})
matplotlib.rc('legend', **{"fancybox": True})
